@@ -238,7 +238,7 @@ def _fetch_worms(aphia_id: int) -> pd.DataFrame:
     try:
         r = requests.get(
             "http://marinespecies.org/rest/AphiaDistributionsByAphiaID/{}".format(
-                aphia_id
+                int(aphia_id)
             )
         )
     except Exception as e:
